@@ -93,7 +93,9 @@ class Session(object):
         *cache* should be an instance of a cache that fulfils the
         :class:`ftrack_api.cache.Cache` interface and will be used as the cache
         for the session. It can also be a callable that will be called with the
-        session instance as sole argument.
+        session instance as sole argument. The callable should return ``None``
+        if a suitable cache could not be configured, but session instantiation
+        can continue safely.
 
         .. note::
 
@@ -197,7 +199,8 @@ class Session(object):
             if callable(cache):
                 cache = cache(self)
 
-            self.cache.caches.append(cache)
+            if cache is not None:
+                self.cache.caches.append(cache)
 
         self._request = requests.Session()
         self._request.auth = SessionAuthentication(
@@ -418,30 +421,6 @@ class Session(object):
         '''
         entity = self._create(entity_type, data, reconstructing=reconstructing)
         entity = self.merge(entity)
-
-        if not reconstructing:
-
-            # Record create operation.
-            # This is done here rather than in the Entity constructor in order
-            # to ensure that all recorded values are fully merged into session.
-            if self.record_operations:
-                entity_data = {}
-
-                # Lower level API used here to avoid including any empty
-                # collections that are automatically generated on access.
-                for attribute in entity.attributes:
-                    value = attribute.get_local_value(entity)
-                    if value is not ftrack_api.symbol.NOT_SET:
-                        entity_data[attribute.name] = value
-
-                self.recorded_operations.push(
-                    ftrack_api.operation.CreateEntityOperation(
-                        entity.entity_type,
-                        ftrack_api.inspection.primary_key(entity),
-                        entity_data
-                    )
-                )
-
         return entity
 
     def _create(self, entity_type, data, reconstructing):
